Struct amazon_sp_sellers::models::participation::Participation
source · [−]Expand description
Participation : Detailed information that is specific to a seller in a Marketplace.
Fields
is_participating: boolhas_suspended_listings: boolSpecifies if the seller has suspended listings. True if the seller Listing Status is set to Inactive, otherwise False.
Implementations
sourceimpl Participation
impl Participation
sourcepub fn new(is_participating: bool, has_suspended_listings: bool) -> Participation
pub fn new(is_participating: bool, has_suspended_listings: bool) -> Participation
Detailed information that is specific to a seller in a Marketplace.